@@ -7,7 +7,7 @@ import threading
 import re
 
 import pyttsx4
-from dotenv import load_dotenv
+from dotenv import load_dotenv, find_dotenv
 from pydub import AudioSegment
 
 import numpy as np
@@ -33,7 +33,7 @@ os.environ["PYGAME_HIDE_SUPPORT_PROMPT"] = "1"
 import pygame
 
 # Ensure environment variables are loaded
-load_dotenv()
+load_dotenv(find_dotenv(), override=True)
 logger = logging.getLogger(__name__)
 
 # FEMALE_VOICE = 'bf_isabella'
@@ -150,37 +150,10 @@ FEMALE_VOICE = {
 }
 
 # # load the voices from environment variables if available
-# SECRET_MALE_VOICE = os.getenv("SECRET_MALE_VOICE")
+secretMaleVoice = os.getenv("SECRET_MALE_VOICE", "").strip().strip('"')
+secretFemaleVoice = os.getenv("SECRET_FEMALE_VOICE", "").strip().strip('"')
 
-# if SECRET_MALE_VOICE:
-#     if SECRET_MALE_VOICE == "male_sybil" or SECRET_MALE_VOICE == "maleSybil":
-#         SECRET_MALE_VOICE = "bm_george"
-#     MALE_VOICE[0] = SECRET_MALE_VOICE
-
-# SECRET_FEMALE_VOICE = os.getenv("SECRET_FEMALE_VOICE")
-
-# if SECRET_FEMALE_VOICE:
-#     if SECRET_FEMALE_VOICE == "female_sybil" or SECRET_FEMALE_VOICE == "femaleSybil":
-#         SECRET_FEMALE_VOICE = "bf_isabella"
-#     FEMALE_VOICE[0] = SECRET_FEMALE_VOICE
-
-# SECRET_ALIASES = {
-#     "male_sybil":   "bm_george",
-#     "maleSybil":    "bm_george",
-#     "female_sybil": "bf_isabella",
-#     "femaleSybil":  "bf_isabella",
-# }
-
-# for env_key, voice_map in (
-#     ("SECRET_MALE_VOICE", MALE_VOICE),
-#     ("SECRET_FEMALE_VOICE", FEMALE_VOICE),
-# ):
-#     secret_val = os.getenv(env_key, "")
-#     secret_val = secret_val.strip() if secret_val else ""
-#     if secret_val:
-#         voice_map[0] = SECRET_ALIASES.get(secret_val, secret_val)
-
-print("DEBUG after injection:", MALE_VOICE, FEMALE_VOICE)
+#print("DEBUG before injection:", MALE_VOICE, FEMALE_VOICE)
 
 # alias mapping (for alternate env values)
 SECRET_ALIASES = {
@@ -190,17 +163,6 @@ SECRET_ALIASES = {
     "femaleSybil":  "bf_isabella",
 }
 
-secretMaleVoice = os.getenv("SECRET_MALE_VOICE", "").strip().strip('"')
-secretFemaleVoice = os.getenv("SECRET_FEMALE_VOICE", "").strip().strip('"')
-
-# if secretMaleVoice:
-#     secretVoice = SECRET_ALIASES.get(secretMaleVoice, secretMaleVoice)
-#     MALE_VOICE.update({0: secretVoice})
-
-# if secretFemaleVoice:
-#     secretVoice = SECRET_ALIASES.get(secretFemaleVoice, secretFemaleVoice)
-#     FEMALE_VOICE.update({0: secretVoice})
-
 if secretMaleVoice:
     MALE_VOICE[0] = SECRET_ALIASES.get(secretMaleVoice, secretMaleVoice)
 
@@ -208,7 +170,7 @@ if secretFemaleVoice:
     FEMALE_VOICE[0] = SECRET_ALIASES.get(secretFemaleVoice, secretFemaleVoice)
 
 
-print("DEBUG after injection:", MALE_VOICE, FEMALE_VOICE)
+#print("DEBUG after injection:", MALE_VOICE, FEMALE_VOICE)
 
 MIN_FACTOR = -12
 MAX_FACTOR = 12
@@ -375,9 +337,9 @@ class HoloTTS:
             self.storedOutput.append(self._cleanContent(text, True))
             gender = self.gender
         
-        if not self.hasRecalibrated:
-            self.setVoice(gender)
-            self.hasRecalibrated = True
+        # if not self.hasRecalibrated:
+        #     self.setVoice(gender)
+        #     self.hasRecalibrated = True
         if gender != self.gender:
             self.setVoice(gender)
         # Use parent synthesisMode if parent has synthesisMode, else self
@@ -534,43 +496,6 @@ class HoloTTS:
             pygame.mixer.music.stop()
             os.replace(temp_file_name, fileName)
 
-    # def resetAttributes(self) -> None:
-    #     self.resetPitch()
-    #     self.resetRate()
-    #     self.resetVoice()
-    #     self.resetVolume()
-    #     self._adjustAttributes()
-    
-    # def resetVoice(self) -> None:
-    #     self.setVoice(self.parent.gender if self.parent else self.gender)
-
-    # def increaseVolume(self, decibels: int = 1) -> None:
-    #     self.decibelFactor = min(self.decibelFactor + decibels, 12)
-
-    # def decreaseVolume(self, decibels: int = 1) -> None:
-    #     self.decibelFactor = max(self.decibelFactor - decibels, -12)
-
-    # def resetVolume(self) -> None:
-    #     self.decibelFactor = 0
-
-    # def increasePitch(self, semitones: int = 1) -> None:
-    #     self.semitoneFactor = min(self.semitoneFactor + semitones, 12)
-
-    # def decreasePitch(self, semitones: int = 1) -> None:
-    #     self.semitoneFactor = max(self.semitoneFactor - semitones, -12)
-
-    # def resetPitch(self) -> None:
-    #     self.semitoneFactor = 0
-
-    # def increaseRate(self, steps: int = 1) -> None:
-    #     self.stepFactor = min(self.stepFactor + steps, 12)
-
-    # def decreaseRate(self, steps: int = 1) -> None:
-    #     self.stepFactor = max(self.stepFactor - steps, -12)
-
-    # def resetRate(self) -> None:
-    #     self.stepFactor = 0
-    # Constants for value limits
     def resetAttributes(self) -> None:
         for prop in ('pitch', 'rate', 'volume', 'voice'):
             self.resetProperty(prop)
